library IEEE;
use IEEE.std_logic_1164.all;  -- defines std_logic types
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

-- Pinout fuer EMCO Compact 5 CNC

use work.IDROMConst.all;

package PIN_7I98_EMCO is
	constant ModuleID : ModuleIDType :=( 
		(HM2DPLLTag,	x"00",	ClockLowTag,	x"01",	HM2DPLLBaseRateAddr&PadT,	HM2DPLLNumRegs,		x"00",	HM2DPLLMPBitMask),
		(WatchDogTag,	x"00",	ClockLowTag,	x"01",	WatchDogTimeAddr&PadT,		WatchDogNumRegs,		x"00",	WatchDogMPBitMask),
		(IOPortTag,		x"00",	ClockLowTag,	x"03",	PortAddr&PadT,					IOPortNumRegs,			x"00",	IOPortMPBitMask),
		(QcountTag,		x"02",	ClockLowTag,	x"03",	QcounterAddr&PadT,			QCounterNumRegs,		x"00",	QCounterMPBitMask),
		(StepGenTag,	x"02",	ClockLowTag,	x"02",	StepGenRateAddr&PadT,		StepGenNumRegs,		x"00",	StepGenMPBitMask),
		(PWMTag,			x"00",	ClockHighTag,	x"05",	PWMValAddr&PadT,				PWMNumRegs,				x"00",	PWMMPBitMask),
		(LEDTag,			x"00",	ClockLowTag,	x"01",	LEDAddr&PadT,					LEDNumRegs,				x"00",	LEDMPBitMask),
		(SSerialTag,	x"00",	ClockLowTag,	x"01",	SSerialCommandAddr&PadT,	SSerialNumRegs,		x"10",	SSerialMPBitMask),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000"),
		(NullTag,		x"00",	NullTag,			x"00",	NullAddr&PadT,					x"00",					x"00",	x"00000000")
		);
		
	
	constant PinDesc : PinDescType :=(
-- 	Base func  sec unit sec func 	 sec pin					-- P1 Achsen und WZW
		IOPortTag & x"00" & StepGenTag & StepGenStepPin,	-- I/O 00	PIN 1		Step Gen Step X
		IOPortTag & x"00" & NullTag & NullPin,					-- I/O 01	PIN 14 	WZW IN2  
		IOPortTag & x"00" & StepGenTag & StepGenDirPin,		-- I/O 02	PIN 2    Step Gen Dir X
		IOPortTag & x"00" & NullTag & NullPin,					-- I/O 03	PIN 15	WZW Pos 1
		IOPortTag & x"01" & StepGenTag & StepGenStepPin,	-- I/O 04	PIN 3		Step Gen Step Z   
		IOPortTag & x"00" & NullTag & NullPin,					-- I/O 05	PIN 16   WZW Pos 2
		IOPortTag & x"01" & StepGenTag & StepGenDirPin,		-- I/O 06	PIN 4		Step Gen Dir Z
		IOPortTag & x"00" & NullTag & NullPin,					-- I/O 07	PIN 17	WZW Pos 3
		IOPortTag & x"00" & NullTag & NullPin,					-- I/O 08	PIN 5 	Fehler Eingang X
		IOPortTag & x"00" & NullTag & NullPin,					-- I/O 09	PIN 6		Fehler Eingang Z
		IOPortTag & x"00" & NullTag & NullPin,					-- I/O 10	PIN 7		Endschalter X+
		IOPortTag & x"00" & NullTag & NullPin,					-- I/O 11	PIN 8		Endschalter X-
		IOPortTag & x"00" & NullTag & NullPin,					-- I/O 12	PIN 9		Endschalter Z+
		IOPortTag & x"00" & NullTag & NullPin,					-- I/O 13	PIN 10	Endschalter Z-
		IOPortTag & x"00" & NullTag & NullPin,  				-- I/O 14	PIN 11	Endschalter Z+ Reitstock
		IOPortTag & x"00" & PWMTag & PWMAOutPin,  			-- I/O 15	PIN 12	WZW EN
		IOPortTag & x"00" & NullTag & NullPin,    			-- I/O 16	PIN 13	WZW IN1
		
																			-- P2 Spindel	
		IOPortTag & x"01" & PWMTag & PWMAOutPin,				-- I/O 17	PIN 1		PIN 1 	Spindle PWM IN1
		IOPortTag & x"00" & NullTag & NullPin,					-- I/O 18   PIN 2		PIN 14	GPIO
		IOPortTag & x"02" & PWMTag & PWMAOutPin,				-- I/O 19   PIN 3		PIN 2	   Spindle PWM IN2
		IOPortTag & x"00" & NullTag & NullPin,					-- I/O 20	PIN 4		PIN 15	GPIO
		IOPortTag & x"03" & PWMTag & PWMAOutPin,				-- I/O 21	PIN 5		PIN 3	   Spindle PWM IN3   
		IOPortTag & x"00" & SSerialTag & SSerialRX1Pin,		-- I/O 22	PIN 6		PIN 16	Smart Serial RX 1
		IOPortTag & x"04" & PWMTag & PWMAOutPin,				-- I/O 23	PIN 7		PIN 4	   Spindle PWM IN4
		IOPortTag & x"00" & SSerialTag & SSerialTX1Pin,		-- I/O 24	PIN 8		PIN 17	Smart Serial TX 1
		IOPortTag & x"00" & NullTag & NullPin,					-- I/O 25	PIN 9		PIN 5	   Spindel EN
		IOPortTag & x"00" & NullTag & NullPin,					-- I/O 26	PIN 11	PIN 6	   Spindel Dir
		IOPortTag & x"00" & QCountTag & QCountQAPin,			-- I/O 27	PIN 13	PIN 7	   Spindel Encoder A
		IOPortTag & x"00" & QCountTag & QCountQBPin,			-- I/O 28	PIN 15	PIN 8	   Spindel Encoder B
		IOPortTag & x"00" & QCountTag & QCountIdxPin,		-- I/O 29	PIN 17	PIN 9	   Spindel Encoder Index
		IOPortTag & x"00" & NullTag & NullPin,					-- I/O 30	PIN 19	PIN 10	GPIO
		IOPortTag & x"00" & NullTag & NullPin,  				-- I/O 31	PIN 21	PIN 11  	GPIO
		IOPortTag & x"00" & NullTag & NullPin,  				-- I/O 32	PIN 23	PIN 12	GPIO
		IOPortTag & x"00" & NullTag & NullPin,    			-- I/O 33	PIN 25	PIN 13	GPIO

																			-- 26 HDR	-- IDC DB25	
		IOPortTag & x"01" & QCountTag & QCountQAPin,			-- I/O 17	PIN 1		PIN 1 	Handrad Encoder X A
		IOPortTag & x"00" & NullTag & NullPin,					-- I/O 18   PIN 2		PIN 14	GPIO
		IOPortTag & x"01" & QCountTag & QCountQBPin,			-- I/O 19   PIN 3		PIN 2	   Handrad Encoder X B
		IOPortTag & x"00" & NullTag & NullPin,					-- I/O 20	PIN 4		PIN 15	GPIO
		IOPortTag & x"01" & QCountTag & QCountIdxPin,		-- I/O 21	PIN 5		PIN 3	   Handrad Encoder X Index    
		IOPortTag & x"00" & SSerialTag & SSerialRX0Pin,		-- I/O 22	PIN 6		PIN 16	Smart Serial RX 0
		IOPortTag & x"02" & QCountTag & QCountQAPin,			-- I/O 23	PIN 7		PIN 4	   Handrad Encoder Z A
		IOPortTag & x"00" & SSerialTag & SSerialTX0Pin,		-- I/O 24	PIN 8		PIN 17	Smart Serial TX 0
		IOPortTag & x"02" & QCountTag & QCountQBPin,			-- I/O 25	PIN 9		PIN 5	   Handrad Encoder Z B
		IOPortTag & x"02" & QCountTag & QCountIdxPin,		-- I/O 26	PIN 11	PIN 6	   Handrad Encoder Z Index
		IOPortTag & x"00" & NullTag & NullPin,					-- I/O 27	PIN 13	PIN 7	   Abnullen X
		IOPortTag & x"00" & NullTag & NullPin,					-- I/O 28	PIN 15	PIN 8	   Abnullen Z
		IOPortTag & x"00" & NullTag & NullPin,					-- I/O 29	PIN 17	PIN 9	   Relativ / absolut
		IOPortTag & x"00" & NullTag & NullPin,					-- I/O 30	PIN 19	PIN 10	Start Taster
		IOPortTag & x"00" & NullTag & NullPin,  				-- I/O 31	PIN 21	PIN 11  	E Stop Taster
		IOPortTag & x"00" & NullTag & NullPin,  				-- I/O 32	PIN 23	PIN 12	Notaus Schalter
		IOPortTag & x"00" & NullTag & NullPin,    			-- I/O 33	PIN 25	PIN 13	GPIO
		

		emptypin,emptypin,emptypin,emptypin,emptypin, -- added for IDROM v3
		emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,
					
		emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,
		emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,
		emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,
		emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,
		emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,
		emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,
		emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,
		emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,
		emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,
		emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin,emptypin);

end package PIN_7I98_EMCO;
